@@ -1,6 +1,6 @@
 
 package Text::Yeti::Table;
-$Text::Yeti::Table::VERSION = '0.2.0';
+$Text::Yeti::Table::VERSION = '0.3.0';
 # ABSTRACT: Render a table like "docker ps" does
 
 use 5.010001;
@@ -56,21 +56,21 @@ sub _compile_table_spec {
 sub _render_table {
     my ( $items, $spec, $io ) = ( shift, shift, shift );
 
-    my $t    = _compile_table_spec($spec);
-    my @spec = @{ $t->{C} };
+    my $t = _compile_table_spec($spec);
+    my $c = $t->{C};
 
     my ( @rows, @len );
 
     # Compute table headers
-    my @h = map { $_->{H} } @spec;
+    my @h = map { $_->{H} } @$c;
     @len = map { length $_ } @h;
 
     # Compute table rows, keep track of max length
-    my @i    = 0 .. $#spec;
-    my @k    = map { $_->{K} } @spec;
-    my @to_s = map { $_->{S} } @spec;
+    my @i = 0 .. $#$c;
+    my @k = map { $_->{K} } @$c;
+    my @s = map { $_->{S} } @$c;
     for my $item (@$items) {
-        my @v = map { $to_s[$_]->( $item->{ $k[$_] }, $item ) } @i;
+        my @v = map { $s[$_]->( $item->{ $k[$_] }, $item ) } @i;
         $len[$_] = max( $len[$_], length $v[$_] ) for @i;
         push @rows, \@v;
     }
@@ -80,7 +80,7 @@ sub _render_table {
         my %x;    # Compute exclusions
         for my $i ( @{ $t->{X} } ) {
             my @c = map { $_->[$i] } @rows;    # Column values
-            $x{$i}++ if $spec[$i]{X}( \@c );
+            $x{$i}++ if $c->[$i]{X}( \@c );
         }
         if (%x) {                              # Exclude
             my @keep = grep { !$x{$_} } @i;
@@ -89,7 +89,9 @@ sub _render_table {
     }
 
     # Compute the table format
-    my $fmt = join( " " x 3, map {"%-${_}s"} @len ) . "\n";
+    my @fmt = map {"%-${_}s"} @len;
+    $fmt[-1] = '%s';
+    my $fmt = join( ' ' x 3, @fmt ) . "\n";
 
     # Render the table
     printf {$io} $fmt, @h;
@@ -260,7 +262,7 @@ Text::Yeti::Table - Render a table like "docker ps" does
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 SYNOPSIS
 
